degal/utils.py
changeset 109 66a01c0806f1
parent 96 d9cf1e272e90
child 120 55cb7fc9c8fb
--- a/degal/utils.py	Thu Jun 11 23:57:53 2009 +0300
+++ b/degal/utils.py	Sun Jun 14 16:19:27 2009 +0300
@@ -68,15 +68,11 @@
     
 class LazyIteratorProperty (LazyProperty) :
     """
         A lazy-loaded property that automatically converts an iterator/genexp into a list.
     """
 
     def run (self, obj) :
-        """
-            Wrap LazyProperty.run to return a list
-        """
-
-        return list(self.func(obj))
+        return tuple(self.func(obj))
 
 lazy_load = LazyProperty
 lazy_load_iter = LazyIteratorProperty
@@ -68,15 +68,11 @@
 class LazyIteratorProperty (LazyProperty) :
     """
-        A lazy-loaded property that automatically converts an iterator/genexp into a list.
+        A lazy-loaded property that automatically converts an iterator/genexp into a non-mutable tuple.
     """
 